# oneNeuron_test1
oneNeuron_test1

# How to use this

```python
from oneNeuron.perceptron import Perceptron
## get X and y and then use below commands
model = Perceptron(eta=eta, epochs=epochs)
model.fit(X, y)

```

# Reference -
[Official python docs](https://packaging.python.org/tutorials/packaging-projects/)

[github docs for github actions](https://docs.github.com/en/actions/guides/building-and-testing-python#publishing-to-package-registries)